package com.huimv.produce.service.impl;

import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.common.utils.DataUill;
import com.huimv.common.utils.PercentUtil;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import com.huimv.produce.entity.ProdCostStatistics;
import com.huimv.produce.entity.ProdSales;
import com.huimv.produce.entity.dto.ClientHomeDto;
import com.huimv.produce.entity.dto.ProdSalesDto;
import com.huimv.produce.mapper.ProdSalesMapper;
import com.huimv.produce.service.IProdSalesService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author astupidcoder
 * @since 2021-11-25
 */
@Service
public class ProdSalesServiceImpl extends ServiceImpl<ProdSalesMapper, ProdSales> implements IProdSalesService {

    @Autowired
    private ProdSalesMapper salesMapper;

    @Override
    public Result listSales(Map map) {
        Integer farmId = (Integer)map.get("farmId");
        Integer type = (Integer)map.get("type");
        String startDate = (String)map.get("startDate");
        String endDate = (String)map.get("endDate");
        QueryWrapper<ProdSales> wrapper = new QueryWrapper<>();
        wrapper.eq("farm_id",farmId);
        Map endMap = new HashMap();
        List<ProdSales> list = new ArrayList<>();
        //本周
        if (1==type){
            wrapper.ge("add_date", DataUill.getTimesWeekmorning());
            wrapper.isNotNull("today_quantity");
            list = this.list(wrapper);
        }//自定义
        else if (3==type) {
            endDate = endDate+" 23:59:59";
            startDate = startDate+" 00:00:00";
            wrapper.between("add_date",startDate,endDate);
            wrapper.isNotNull("today_quantity");
            list = this.list(wrapper);
        }
        //本月
        else {
            wrapper.ge("add_date", DataUill.getTimesMonthmorning());
            wrapper.isNotNull("today_quantity");
            list = this.list(wrapper);
        }
        wrapper.clear();

        wrapper.eq("farm_id",farmId);
        wrapper.last("AND PERIOD_DIFF( DATE_FORMAT( NOW( ) , '%Y%m' ) , DATE_FORMAT( add_date, '%Y%m' ) ) =1  ");
        ProdSalesDto lastProdSales = salesMapper.countMonth(wrapper);


        wrapper.clear();

        wrapper.eq("farm_id",farmId);
        wrapper.last("AND PERIOD_DIFF( DATE_FORMAT( NOW( ) , '%Y%m' ) , DATE_FORMAT( add_date, '%Y%m' ) ) =2  ");
        ProdSalesDto lastTwoProdSales = salesMapper.countMonth(wrapper);

        List timeList = new ArrayList();
        List moneyList = new ArrayList();
        List quantityList = new ArrayList();


        for (ProdSales prodSales : list) {
            timeList.add(DateUtil.format(prodSales.getAddDate(),"MM-dd"));
            moneyList.add(  prodSales.getTodayMoney());
            quantityList.add(  prodSales.getTodayQuantity());
        }

        endMap.put("timeList",timeList);
        endMap.put("moneyList",moneyList);
        endMap.put("quantityList",quantityList);


        endMap.put("quantity",lastProdSales.getQuantity());
        endMap.put("quantityPercent", PercentUtil.getGrowth(lastProdSales.getQuantity(),lastTwoProdSales.getQuantity()));
        endMap.put("money",lastProdSales.getMoney());
        endMap.put("moneyPercent", PercentUtil.getGrowth(lastProdSales.getMoney(),lastTwoProdSales.getMoney()));
        return new Result(ResultCode.SUCCESS,endMap);
    }

    @Override
    public Result listClientHome(Integer farmId) {
        ClientHomeDto clientHomeDto = salesMapper.listClientHome(farmId);
        return new Result(ResultCode.SUCCESS,clientHomeDto);
    }


}
